TheanoLM
========

Welcome to TheanoLM documentation. See About section for a short introduction to
the project. Getting Started provides a tutorial on how to get started with
training neural network language models and performing various operations with
them. The development documentation is intended to help extending the toolkit.

About
-----

.. toctree::
   :maxdepth: 2

   about

Getting Started
---------------

.. toctree::
   :maxdepth: 2

   installation
   usage
   training
   applying

Development
-----------

.. toctree::
   :maxdepth: 2

   contributing
   api

Indices and Tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
